@@ -92,7 +92,7 @@ describe Money, "formatting" do
         I18n.locale = :de
         I18n.backend.store_translations(
             :de,
-            number: { currency: { format: { delimiter: ".", separator: "," } } }
+            number: { currency: { format: { delimiter: ".", separator: ",", delimiter_pattern: /(\d)(?=\d)/ } } }
         )
       end
 
@@ -105,6 +105,10 @@ describe Money, "formatting" do
       it "should use ',' as the decimal mark" do
         expect(money.decimal_mark).to eq ','
       end
+
+      it "should use delimiter pattern" do
+        expect(Money.new(1_456_00, "EUR").format).to eq "€1.4.5.6,00"
+      end
     end
 
     context "with number.currency.symbol.*" do
@@ -158,7 +162,7 @@ describe Money, "formatting" do
     end
 
     it "respects :subunit_to_unit currency property" do
-      expect(Money.new(10_00, "BHD").format).to eq "ب.د1.000"
+      expect(Money.new(10_00, "BHD").format).to eq "د.ب1.000"
     end
 
     context "when :subunit_to_unit is 1" do
@@ -271,7 +275,7 @@ describe Money, "formatting" do
       end
 
       it "respects :subunit_to_unit currency property" do
-        expect(Money.new(10_00, "BHD").format(no_cents: true)).to eq "ب.د1"
+        expect(Money.new(10_00, "BHD").format(no_cents: true)).to eq "د.ب1"
       end
 
       it "inserts thousand separators if symbol contains decimal mark and no_cents is true" do
@@ -613,8 +617,8 @@ describe Money, "formatting" do
       it "does round fractional when set to true" do
         expect(Money.new(BigDecimal('12.1'), "USD").format(rounded_infinite_precision: true)).to eq "$0.12"
         expect(Money.new(BigDecimal('12.5'), "USD").format(rounded_infinite_precision: true)).to eq "$0.13"
-        expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: true)).to eq "ب.د0.123"
-        expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: true)).to eq "ب.د0.124"
+        expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: true)).to eq "د.ب0.123"
+        expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: true)).to eq "د.ب0.124"
         expect(Money.new(BigDecimal('100.1'), "USD").format(rounded_infinite_precision: true)).to eq "$1.00"
         expect(Money.new(BigDecimal('109.5'), "USD").format(rounded_infinite_precision: true)).to eq "$1.10"
         expect(Money.new(BigDecimal('1.7'), "MGA").format(rounded_infinite_precision: true)).to eq "Ar0.4"
@@ -623,8 +627,10 @@ describe Money, "formatting" do
       it "does not round fractional when set to false" do
         expect(Money.new(BigDecimal('12.1'), "USD").format(rounded_infinite_precision: false)).to eq "$0.121"
         expect(Money.new(BigDecimal('12.5'), "USD").format(rounded_infinite_precision: false)).to eq "$0.125"
-        expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: false)).to eq "ب.د0.1231"
-        expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: false)).to eq "ب.د0.1235"
+        expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: false)).to eq "د.ب0.1231"
+        expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: false)).to eq "د.ب0.1235"
+        expect(Money.new(BigDecimal('123.1'), "KWD").format(rounded_infinite_precision: false)).to eq "د.ك0.1231"
+        expect(Money.new(BigDecimal('123.5'), "KWD").format(rounded_infinite_precision: false)).to eq "د.ك0.1235"
         expect(Money.new(BigDecimal('100.1'), "USD").format(rounded_infinite_precision: false)).to eq "$1.001"
         expect(Money.new(BigDecimal('109.5'), "USD").format(rounded_infinite_precision: false)).to eq "$1.095"
         expect(Money.new(BigDecimal('1.7'), "MGA").format(rounded_infinite_precision: false)).to eq "Ar0.34"
@@ -669,8 +675,8 @@ describe Money, "formatting" do
         it 'does round fractional when set to true' do
           expect(Money.new(BigDecimal('12.1'), "USD").format(rounded_infinite_precision: true)).to eq "$0,12"
           expect(Money.new(BigDecimal('12.5'), "USD").format(rounded_infinite_precision: true)).to eq "$0,13"
-          expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: true)).to eq "ب.د0,123"
-          expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: true)).to eq "ب.د0,124"
+          expect(Money.new(BigDecimal('123.1'), "BHD").format(rounded_infinite_precision: true)).to eq "د.ب0,123"
+          expect(Money.new(BigDecimal('123.5'), "BHD").format(rounded_infinite_precision: true)).to eq "د.ب0,124"
           expect(Money.new(BigDecimal('100.1'), "USD").format(rounded_infinite_precision: true)).to eq "$1,00"
           expect(Money.new(BigDecimal('109.5'), "USD").format(rounded_infinite_precision: true)).to eq "$1,10"
           expect(Money.new(BigDecimal('1'), "MGA").format(rounded_infinite_precision: true)).to eq "Ar0,2"
@@ -733,16 +739,10 @@ describe Money, "formatting" do
     end
   end
 
-  describe ':format to "%u %n" for currency with :symbol_first to true' do
+  describe ':format to "%u%n" for currency with :symbol_first to true' do
     context 'when rules are not passed' do
-      it "insert space between symbol and number" do
-        expect(Money.new(100_00, 'CHF').format).to eq "CHF 100.00"
-      end
-    end
-
-    context 'when format: "%u%n" rule is passed' do
-      it "ignores :symbol_with_space in favour of format" do
-        expect(Money.new(100_00, 'CHF').format(format: '%u%n')).to eq "CHF100.00"
+      it "does not insert space between symbol and number" do
+        expect(Money.new(100_00, 'CHF').format).to eq "CHF100.00"
       end
     end
 
@@ -774,12 +774,6 @@ describe Money, "formatting" do
       end
     end
 
-    context 'when format: "%u%n" rule is passed' do
-      it "ignores :symbol_with_space in favour of format" do
-        expect(Money.new(100_00, 'AED').format(format: '%u%n')).to eq "د.إ100.00"
-      end
-    end
-
     context 'when symbol_position is passed' do
       it "inserts currency symbol before the amount when set to :before" do
         expect(Money.new(100_00, 'AED').format(symbol_position: :before)).to eq "د.إ100.00"
